"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.DatadogCodepushProvider = exports.DatadogCodepush = void 0;
var _mobileReactNative = require("@datadog/mobile-react-native");
var _reactNativeCodePush = _interopRequireDefault(require("react-native-code-push"));
function _interopRequireDefault(e) { return e && e.__esModule ? e : { default: e }; }
/**
 * Use this class instead of DdSdkReactNative to initialize the Datadog SDK when using AppCenter CodePush.
 */
const DatadogCodepush = exports.DatadogCodepush = {
  async initialize(configuration) {
    const codePushUpdateMetadata = await _reactNativeCodePush.default.getUpdateMetadata();
    if (codePushUpdateMetadata) {
      configuration.versionSuffix = `codepush.${codePushUpdateMetadata.label}`;
    }
    return _mobileReactNative.DdSdkReactNative.initialize(configuration);
  }
};
const initializeWithCodepushVersion = async configuration => {
  const codePushUpdateMetadata = await _reactNativeCodePush.default.getUpdateMetadata();
  if (codePushUpdateMetadata) {
    configuration.versionSuffix = `codepush.${codePushUpdateMetadata.label}`;
  }
  _mobileReactNative.DatadogProvider.initialize(configuration);
};
const DatadogCodepushProvider = ({
  configuration,
  ...rest
}) => {
  // We cannot use SYNC or ASYNC initialization modes as we need to asynchronously get the CodePush version.
  // We turn it to partial initialization, while in parallel we get the CodePush version and initialize the SDK.
  if (configuration instanceof _mobileReactNative.DatadogProviderConfiguration) {
    initializeWithCodepushVersion(configuration);
    const partialConfiguration = {
      trackErrors: configuration.trackErrors,
      trackResources: configuration.trackResources,
      trackInteractions: configuration.trackInteractions,
      firstPartyHosts: configuration.firstPartyHosts,
      resourceTracingSamplingRate: configuration.resourceTracingSamplingRate
    };
    return (0, _mobileReactNative.DatadogProvider)({
      configuration: partialConfiguration,
      ...rest
    });
  } else {
    return (0, _mobileReactNative.DatadogProvider)({
      configuration,
      ...rest
    });
  }
};
exports.DatadogCodepushProvider = DatadogCodepushProvider;
DatadogCodepushProvider.initialize = async configuration => {
  const codePushUpdateMetadata = await _reactNativeCodePush.default.getUpdateMetadata();
  if (codePushUpdateMetadata) {
    configuration.versionSuffix = `codepush.${codePushUpdateMetadata.label}`;
  }
  _mobileReactNative.DatadogProvider.initialize(configuration);
};
//# sourceMappingURL=index.js.map